#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Polygon, PolyLine, Circle, Line
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor
from rlextra.graphics.canvasadapter import DirectDrawFlowable

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Polygon(points=[55.26472,117.9412,95,133.2353,134.7353,117.9412,141.3578,68.23529,95,33.82353,48.64217,68.23529,55.26472,117.9412],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[45.3309,123.6765,95,117.9412,121.4902,110.2941,128.1127,75.88235,95,49.11765,65.19854,77.79412,45.3309,123.6765],fillColor=Color(.678431,.847059,.901961,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[68.50981,110.2941,95,121.7647,121.4902,110.2941,151.2917,62.5,95,79.70588,55.26472,72.05882,68.50981,110.2941],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=None,strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[55.26472,117.9412,95,133.2353,134.7353,117.9412,141.3578,68.23529,95,33.82353,48.64217,68.23529,55.26472,117.9412],strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[45.3309,123.6765,95,117.9412,121.4902,110.2941,128.1127,75.88235,95,49.11765,65.19854,77.79412,45.3309,123.6765],strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[68.50981,110.2941,95,121.7647,121.4902,110.2941,151.2917,62.5,95,79.70588,55.26472,72.05882,68.50981,110.2941],strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,133.2353,95,136.2353,98,133.2353,95,130.2353],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[131.7353,117.9412,134.7353,120.9412,137.7353,117.9412,134.7353,114.9412],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[138.3578,68.23529,141.3578,71.23529,144.3578,68.23529,141.3578,65.23529],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,33.82353,95,36.82353,98,33.82353,95,30.82353],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[45.64217,68.23529,48.64217,71.23529,51.64217,68.23529,48.64217,65.23529],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[52.26472,117.9412,55.26472,120.9412,58.26472,117.9412,55.26472,114.9412],fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(95,117.9412,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(121.4902,110.2941,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(128.1127,75.88235,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(95,49.11765,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(65.19854,77.79412,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(45.3309,123.6765,2.5,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,121.7647,95,124.7647,98,121.7647,95,118.7647],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[118.4902,110.2941,121.4902,113.2941,124.4902,110.2941,121.4902,107.2941],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[148.2917,62.5,151.2917,65.5,154.2917,62.5,151.2917,59.5],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[92,79.70588,95,82.70588,98,79.70588,95,76.70588],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[52.26472,72.05882,55.26472,75.05882,58.26472,72.05882,55.26472,69.05882],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Polygon(points=[65.50981,110.2941,68.50981,113.2941,71.50981,110.2941,68.50981,107.2941],fillColor=Color(.596078,.984314,.596078,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(95,95,95,160,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,169.75)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-6.20459,-10)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': '<u>U<sup><span color="red">2</span></sup></u><br/>3'
'frags': [[12.4091796875, (ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='U', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), 'U'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), '2')], [0, (ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[]), '')], [6.3623046875, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='3', textColor=Color(0,0,0,1), us_lines=[]), '3')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 12.4091796875
'_wrapWidths': [12.4091796875, 12.4091796875]
'_width_max': 12.4091796875
'height': 20.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=True, maxWidth=12.4091796875, sFW=0, wordCount=1, words=[ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='U', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[])]), FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=6.046875, fontSize=10, lineBreak=False, maxWidth=12.4091796875, sFW=1, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='3', textColor=Color(0,0,0,1), us_lines=[])])])
) #Paragraph))
		self.add(Line(95,95,151.2917,127.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,159.7354,132.375)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-5.965332,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'V<sup><span color="red">3</span></sup>'
'frags': [[11.9306640625, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='V', textColor=Color(0,0,0,1), us_lines=[]), 'V'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='3', textColor=Color(1,0,0,1), us_lines=[]), '3')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 11.9306640625
'_wrapWidths': [11.9306640625, 11.9306640625]
'_width_max': 11.9306640625
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=False, maxWidth=11.9306640625, sFW=0, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='V', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='3', textColor=Color(1,0,0,1), us_lines=[])])])
) #Paragraph))
		self.add(Line(95,95,151.2917,62.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,159.7354,57.625)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-4.943848,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'W'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='W', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 9.8876953125
'_wrapWidths': [9.8876953125, 9.8876953125]
'_width_max': 9.8876953125
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['W'])], link=[], rise=0, text='W', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		self.add(Line(95,95,95,30,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,20.25)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-3.425293,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'X'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='X', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 6.8505859375
'_wrapWidths': [6.8505859375, 6.8505859375]
'_width_max': 6.8505859375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['X'])], link=[], rise=0, text='X', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		self.add(Line(95,95,38.70835,62.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,30.2646,57.625)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-3.054199,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Y'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Y', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 6.1083984375
'_wrapWidths': [6.1083984375, 6.1083984375]
'_width_max': 6.1083984375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['Y'])], link=[], rise=0, text='Y', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		self.add(Line(95,95,38.70835,127.5,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,30.2646,132.375)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-3.425293,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Z'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Z', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 6.8505859375
'_wrapWidths': [6.8505859375, 6.8505859375]
'_width_max': 6.8505859375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(0.0, ['Z'])], link=[], rise=0, text='Z', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,128.2353)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-10.81543,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'zero'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='zero', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 21.630859375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483625.3691406, ['zero'])], link=[], rise=0, text='zero', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,130.4052,115.4412)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-9.304199,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'one'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='one', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 18.6083984375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483628.3916016, ['one'])], link=[], rise=0, text='one', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,38.82353)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-17.44629,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'special'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='special', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 34.892578125
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483612.1074219, ['special'])], link=[], rise=0, text='special', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,95,110.9412)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-15.95312,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Earth<sup>1</sup>'
'frags': [[31.90625, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Earth', textColor=Color(0,0,0,1), us_lines=[]), 'Earth'), (ParaFrag(__tag__='super', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='1', textColor=Color(0,0,0,1), us_lines=[]), '1')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 31.90625
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=2147483615.09375, fontSize=10, lineBreak=False, maxWidth=2147483647, sFW=0, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Earth', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='super', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='1', textColor=Color(0,0,0,1), us_lines=[])])])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,146.9615,65)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-12.03857,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'Mars'
'frags': [ParaFrag(__tag__='para', bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='Mars', textColor=Color(0,0,0,1), us_lines=[])]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 2147483647
'_wrapWidths': [2147483647, 2147483647]
'_width_max': 24.0771484375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaFrag(__tag__='para', ascent=7.59765625, bold=1, descent=-2.40234375, fontName='Vera', fontSize=10, greek=0, italic=1, kind=0, lines=[(2147483622.9228516, ['Mars'])], link=[], rise=0, text='Mars', textColor=Color(0,0,0,1), us_lines=[])
) #Paragraph))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
