#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Wedge
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor
from rlextra.graphics.canvasadapter import DirectDrawFlowable

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Wedge(95,95,65,-90,90,yradius=65,annular=False,fillColor=Color(0,.545098,.545098,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=26,yradius1=26))
		self.add(Wedge(95,95,65,-270,-90,yradius=65,annular=False,fillColor=Color(.541176,.168627,.886275,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=0,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None,radius1=26,yradius1=26))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,173,95)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,0,-10)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': '<u>a<sup><span color="red">2</span></sup></u><br/>2'
'frags': [[11.2177734375, (ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='a', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), 'a'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), '2')], [0, (ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[]), '')], [6.3623046875, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='2', textColor=Color(0,0,0,1), us_lines=[]), '2')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 11.2177734375
'_wrapWidths': [11.2177734375, 11.2177734375]
'_width_max': 11.2177734375
'height': 20.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=True, maxWidth=11.2177734375, sFW=0, wordCount=1, words=[ParaFrag(__tag__='u', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='a', textColor=Color(0,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[(0, 'underline', None, '', '-0.125*F', 0, 1, '1')]), ParaFrag(__tag__='br', _fkind=3, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, lineBreak=True, link=[], rise=0, text='', textColor=Color(0,0,0,1), us_lines=[])]), FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=4.85546875, fontSize=10, lineBreak=False, maxWidth=11.2177734375, sFW=1, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='2', textColor=Color(0,0,0,1), us_lines=[])])])
) #Paragraph))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,17,95)
		v1=v0._nn(Group())
		v1.transform = (1,0,0,1,-11.4375,-5)
		v1.add(DirectDrawFlowable(Paragraph(
'caseSensitive': 1
'encoding': 'utf8'
'text': 'b<sup><span color="red">2</span></sup>'
'frags': [[11.4375, (ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='b', textColor=Color(0,0,0,1), us_lines=[]), 'b'), (ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[]), '2')]]
'style': <ParagraphStyle 'xlabel-generated'>
'bulletText': None
'debug': 0
'width': 11.4375
'_wrapWidths': [11.4375, 11.4375]
'_width_max': 11.4375
'height': 10.0
'_splitLongWordCount': 0
'_hyphenations': 0
'blPara': ParaLines(kind=1, lines=[FragLine(ascent=7.59765625, descent=-2.40234375, extraSpace=0.0, fontSize=10, lineBreak=False, maxWidth=11.4375, sFW=0, wordCount=1, words=[ParaFrag(__tag__='para', _fkind=0, bold=1, fontName='Vera', fontSize=10, greek=0, italic=1, link=[], rise=0, text='b', textColor=Color(0,0,0,1), us_lines=[]), ParaFrag(__tag__='span', _fkind=0, bold=1, fontName='Vera', fontSize=8, greek=0, italic=1, link=[], rise=5.0, text='2', textColor=Color(1,0,0,1), us_lines=[])])])
) #Paragraph))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
