#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, String, Polygon
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=167.6062992125984,height=40.66141732283465,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,5,18.37008)
		v0.add(Rect(0,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.909804,.878431,.466667,1),fillOpacity=None,strokeColor=Color(.909804,.878431,.466667,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(.689764,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.905805,.875592,.466976,1),fillOpacity=None,strokeColor=Color(.905805,.875592,.466976,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(1.379528,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.901806,.872752,.467285,1),fillOpacity=None,strokeColor=Color(.901806,.872752,.467285,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(2.069291,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.897807,.869912,.467594,1),fillOpacity=None,strokeColor=Color(.897807,.869912,.467594,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(2.759055,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.893809,.867072,.467903,1),fillOpacity=None,strokeColor=Color(.893809,.867072,.467903,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(3.448819,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.88981,.864233,.468212,1),fillOpacity=None,strokeColor=Color(.88981,.864233,.468212,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(4.138583,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.885811,.861393,.468521,1),fillOpacity=None,strokeColor=Color(.885811,.861393,.468521,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(4.828346,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.881812,.858553,.46883,1),fillOpacity=None,strokeColor=Color(.881812,.858553,.46883,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(5.51811,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.877813,.855713,.469139,1),fillOpacity=None,strokeColor=Color(.877813,.855713,.469139,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(6.207874,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.873814,.852874,.469448,1),fillOpacity=None,strokeColor=Color(.873814,.852874,.469448,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(6.897638,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.869816,.850034,.469758,1),fillOpacity=None,strokeColor=Color(.869816,.850034,.469758,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(7.587402,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.865817,.847194,.470067,1),fillOpacity=None,strokeColor=Color(.865817,.847194,.470067,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(8.277165,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.861818,.844354,.470376,1),fillOpacity=None,strokeColor=Color(.861818,.844354,.470376,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(8.966929,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.857819,.841515,.470685,1),fillOpacity=None,strokeColor=Color(.857819,.841515,.470685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(9.656693,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.85382,.838675,.470994,1),fillOpacity=None,strokeColor=Color(.85382,.838675,.470994,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(10.34646,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.849821,.835835,.471303,1),fillOpacity=None,strokeColor=Color(.849821,.835835,.471303,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(11.03622,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.845822,.832995,.471612,1),fillOpacity=None,strokeColor=Color(.845822,.832995,.471612,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(11.72598,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.841824,.830156,.471921,1),fillOpacity=None,strokeColor=Color(.841824,.830156,.471921,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(12.41575,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.837825,.827316,.47223,1),fillOpacity=None,strokeColor=Color(.837825,.827316,.47223,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(13.10551,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.833826,.824476,.472539,1),fillOpacity=None,strokeColor=Color(.833826,.824476,.472539,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(13.79528,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.829827,.821636,.472848,1),fillOpacity=None,strokeColor=Color(.829827,.821636,.472848,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(14.48504,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.825828,.818796,.473158,1),fillOpacity=None,strokeColor=Color(.825828,.818796,.473158,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(15.1748,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.821829,.815957,.473467,1),fillOpacity=None,strokeColor=Color(.821829,.815957,.473467,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(15.86457,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.817831,.813117,.473776,1),fillOpacity=None,strokeColor=Color(.817831,.813117,.473776,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(16.55433,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.813832,.810277,.474085,1),fillOpacity=None,strokeColor=Color(.813832,.810277,.474085,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(17.24409,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.809833,.807437,.474394,1),fillOpacity=None,strokeColor=Color(.809833,.807437,.474394,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(17.93386,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.805834,.804598,.474703,1),fillOpacity=None,strokeColor=Color(.805834,.804598,.474703,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(18.62362,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.801835,.801758,.475012,1),fillOpacity=None,strokeColor=Color(.801835,.801758,.475012,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(19.31339,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.797836,.798918,.475321,1),fillOpacity=None,strokeColor=Color(.797836,.798918,.475321,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(20.00315,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.793838,.796078,.47563,1),fillOpacity=None,strokeColor=Color(.793838,.796078,.47563,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(0,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(10.34646,4.205276,'1',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Rect(22.8189,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.793838,.796078,.47563,1),fillOpacity=None,strokeColor=Color(.793838,.796078,.47563,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(23.50866,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.789839,.793239,.475939,1),fillOpacity=None,strokeColor=Color(.789839,.793239,.475939,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(24.19843,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.78584,.790399,.476248,1),fillOpacity=None,strokeColor=Color(.78584,.790399,.476248,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(24.88819,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.781841,.787559,.476558,1),fillOpacity=None,strokeColor=Color(.781841,.787559,.476558,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(25.57795,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.777842,.784719,.476867,1),fillOpacity=None,strokeColor=Color(.777842,.784719,.476867,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(26.26772,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.773843,.78188,.477176,1),fillOpacity=None,strokeColor=Color(.773843,.78188,.477176,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(26.95748,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.769844,.77904,.477485,1),fillOpacity=None,strokeColor=Color(.769844,.77904,.477485,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(27.64724,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.765846,.7762,.477794,1),fillOpacity=None,strokeColor=Color(.765846,.7762,.477794,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(28.33701,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.761847,.77336,.478103,1),fillOpacity=None,strokeColor=Color(.761847,.77336,.478103,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(29.02677,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.757848,.770521,.478412,1),fillOpacity=None,strokeColor=Color(.757848,.770521,.478412,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(29.71654,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.753849,.767681,.478721,1),fillOpacity=None,strokeColor=Color(.753849,.767681,.478721,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(30.4063,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.74985,.764841,.47903,1),fillOpacity=None,strokeColor=Color(.74985,.764841,.47903,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(31.09606,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.745851,.762001,.479339,1),fillOpacity=None,strokeColor=Color(.745851,.762001,.479339,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(31.78583,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.741853,.759162,.479648,1),fillOpacity=None,strokeColor=Color(.741853,.759162,.479648,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(32.47559,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.737854,.756322,.479958,1),fillOpacity=None,strokeColor=Color(.737854,.756322,.479958,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(33.16535,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.733855,.753482,.480267,1),fillOpacity=None,strokeColor=Color(.733855,.753482,.480267,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(33.85512,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.729856,.750642,.480576,1),fillOpacity=None,strokeColor=Color(.729856,.750642,.480576,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(34.54488,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.725857,.747803,.480885,1),fillOpacity=None,strokeColor=Color(.725857,.747803,.480885,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(35.23465,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.721858,.744963,.481194,1),fillOpacity=None,strokeColor=Color(.721858,.744963,.481194,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(35.92441,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.71786,.742123,.481503,1),fillOpacity=None,strokeColor=Color(.71786,.742123,.481503,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(36.61417,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.713861,.739283,.481812,1),fillOpacity=None,strokeColor=Color(.713861,.739283,.481812,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(37.30394,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.709862,.736444,.482121,1),fillOpacity=None,strokeColor=Color(.709862,.736444,.482121,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(37.9937,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.705863,.733604,.48243,1),fillOpacity=None,strokeColor=Color(.705863,.733604,.48243,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(38.68346,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.701864,.730764,.482739,1),fillOpacity=None,strokeColor=Color(.701864,.730764,.482739,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(39.37323,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.697865,.727924,.483048,1),fillOpacity=None,strokeColor=Color(.697865,.727924,.483048,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(40.06299,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.693867,.725085,.483357,1),fillOpacity=None,strokeColor=Color(.693867,.725085,.483357,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(40.75276,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.689868,.722245,.483667,1),fillOpacity=None,strokeColor=Color(.689868,.722245,.483667,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(41.44252,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.685869,.719405,.483976,1),fillOpacity=None,strokeColor=Color(.685869,.719405,.483976,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(42.13228,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.68187,.716565,.484285,1),fillOpacity=None,strokeColor=Color(.68187,.716565,.484285,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(42.82205,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.677871,.713725,.484594,1),fillOpacity=None,strokeColor=Color(.677871,.713725,.484594,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(22.8189,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(33.16535,4.205276,'2',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Rect(45.6378,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.677871,.713725,.484594,1),fillOpacity=None,strokeColor=Color(.677871,.713725,.484594,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(46.32756,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.673872,.710886,.484903,1),fillOpacity=None,strokeColor=Color(.673872,.710886,.484903,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(47.01732,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.669873,.708046,.485212,1),fillOpacity=None,strokeColor=Color(.669873,.708046,.485212,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(47.70709,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.665875,.705206,.485521,1),fillOpacity=None,strokeColor=Color(.665875,.705206,.485521,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(48.39685,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.661876,.702366,.48583,1),fillOpacity=None,strokeColor=Color(.661876,.702366,.48583,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(49.08661,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.657877,.699527,.486139,1),fillOpacity=None,strokeColor=Color(.657877,.699527,.486139,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(49.77638,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.653878,.696687,.486448,1),fillOpacity=None,strokeColor=Color(.653878,.696687,.486448,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(50.46614,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.649879,.693847,.486757,1),fillOpacity=None,strokeColor=Color(.649879,.693847,.486757,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(51.15591,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.64588,.691007,.487067,1),fillOpacity=None,strokeColor=Color(.64588,.691007,.487067,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(51.84567,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.641882,.688168,.487376,1),fillOpacity=None,strokeColor=Color(.641882,.688168,.487376,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(52.53543,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.637883,.685328,.487685,1),fillOpacity=None,strokeColor=Color(.637883,.685328,.487685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(53.2252,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.633884,.682488,.487994,1),fillOpacity=None,strokeColor=Color(.633884,.682488,.487994,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(53.91496,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.629885,.679648,.488303,1),fillOpacity=None,strokeColor=Color(.629885,.679648,.488303,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(54.60472,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.625886,.676809,.488612,1),fillOpacity=None,strokeColor=Color(.625886,.676809,.488612,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(55.29449,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.621887,.673969,.488921,1),fillOpacity=None,strokeColor=Color(.621887,.673969,.488921,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(55.98425,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.617889,.671129,.48923,1),fillOpacity=None,strokeColor=Color(.617889,.671129,.48923,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(56.67402,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.61389,.668289,.489539,1),fillOpacity=None,strokeColor=Color(.61389,.668289,.489539,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(57.36378,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.609891,.66545,.489848,1),fillOpacity=None,strokeColor=Color(.609891,.66545,.489848,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(58.05354,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.605892,.66261,.490157,1),fillOpacity=None,strokeColor=Color(.605892,.66261,.490157,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(58.74331,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.601893,.65977,.490467,1),fillOpacity=None,strokeColor=Color(.601893,.65977,.490467,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(59.43307,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.597894,.65693,.490776,1),fillOpacity=None,strokeColor=Color(.597894,.65693,.490776,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(60.12283,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.593895,.654091,.491085,1),fillOpacity=None,strokeColor=Color(.593895,.654091,.491085,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(60.8126,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.589897,.651251,.491394,1),fillOpacity=None,strokeColor=Color(.589897,.651251,.491394,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(61.50236,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.585898,.648411,.491703,1),fillOpacity=None,strokeColor=Color(.585898,.648411,.491703,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(62.19213,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.581899,.645571,.492012,1),fillOpacity=None,strokeColor=Color(.581899,.645571,.492012,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(62.88189,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.5779,.642732,.492321,1),fillOpacity=None,strokeColor=Color(.5779,.642732,.492321,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(63.57165,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.573901,.639892,.49263,1),fillOpacity=None,strokeColor=Color(.573901,.639892,.49263,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(64.26142,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.569902,.637052,.492939,1),fillOpacity=None,strokeColor=Color(.569902,.637052,.492939,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(64.95118,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.565904,.634212,.493248,1),fillOpacity=None,strokeColor=Color(.565904,.634212,.493248,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(65.64094,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.561905,.631373,.493557,1),fillOpacity=None,strokeColor=Color(.561905,.631373,.493557,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(45.6378,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(55.98425,4.205276,'3',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Rect(68.45669,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.561905,.631373,.493557,1),fillOpacity=None,strokeColor=Color(.561905,.631373,.493557,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(69.14646,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.557906,.628533,.493867,1),fillOpacity=None,strokeColor=Color(.557906,.628533,.493867,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(69.83622,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.553907,.625693,.494176,1),fillOpacity=None,strokeColor=Color(.553907,.625693,.494176,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(70.52598,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.549908,.622853,.494485,1),fillOpacity=None,strokeColor=Color(.549908,.622853,.494485,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(71.21575,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.545909,.620014,.494794,1),fillOpacity=None,strokeColor=Color(.545909,.620014,.494794,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(71.90551,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.541911,.617174,.495103,1),fillOpacity=None,strokeColor=Color(.541911,.617174,.495103,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(72.59528,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.537912,.614334,.495412,1),fillOpacity=None,strokeColor=Color(.537912,.614334,.495412,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(73.28504,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.533913,.611494,.495721,1),fillOpacity=None,strokeColor=Color(.533913,.611494,.495721,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(73.9748,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.529914,.608654,.49603,1),fillOpacity=None,strokeColor=Color(.529914,.608654,.49603,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(74.66457,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.525915,.605815,.496339,1),fillOpacity=None,strokeColor=Color(.525915,.605815,.496339,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(75.35433,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.521916,.602975,.496648,1),fillOpacity=None,strokeColor=Color(.521916,.602975,.496648,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(76.04409,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.517918,.600135,.496957,1),fillOpacity=None,strokeColor=Color(.517918,.600135,.496957,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(76.73386,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.513919,.597295,.497266,1),fillOpacity=None,strokeColor=Color(.513919,.597295,.497266,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(77.42362,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.50992,.594456,.497576,1),fillOpacity=None,strokeColor=Color(.50992,.594456,.497576,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(78.11339,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.505921,.591616,.497885,1),fillOpacity=None,strokeColor=Color(.505921,.591616,.497885,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(78.80315,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.501922,.588776,.498194,1),fillOpacity=None,strokeColor=Color(.501922,.588776,.498194,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(79.49291,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.497923,.585936,.498503,1),fillOpacity=None,strokeColor=Color(.497923,.585936,.498503,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(80.18268,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.493924,.583097,.498812,1),fillOpacity=None,strokeColor=Color(.493924,.583097,.498812,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(80.87244,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.489926,.580257,.499121,1),fillOpacity=None,strokeColor=Color(.489926,.580257,.499121,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(81.5622,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.485927,.577417,.49943,1),fillOpacity=None,strokeColor=Color(.485927,.577417,.49943,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(82.25197,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.481928,.574577,.499739,1),fillOpacity=None,strokeColor=Color(.481928,.574577,.499739,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(82.94173,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.477929,.571738,.500048,1),fillOpacity=None,strokeColor=Color(.477929,.571738,.500048,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(83.6315,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.47393,.568898,.500357,1),fillOpacity=None,strokeColor=Color(.47393,.568898,.500357,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(84.32126,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.469931,.566058,.500666,1),fillOpacity=None,strokeColor=Color(.469931,.566058,.500666,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(85.01102,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.465933,.563218,.500976,1),fillOpacity=None,strokeColor=Color(.465933,.563218,.500976,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(85.70079,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.461934,.560379,.501285,1),fillOpacity=None,strokeColor=Color(.461934,.560379,.501285,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(86.39055,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.457935,.557539,.501594,1),fillOpacity=None,strokeColor=Color(.457935,.557539,.501594,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(87.08031,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.453936,.554699,.501903,1),fillOpacity=None,strokeColor=Color(.453936,.554699,.501903,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(87.77008,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.449937,.551859,.502212,1),fillOpacity=None,strokeColor=Color(.449937,.551859,.502212,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(88.45984,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.445938,.54902,.502521,1),fillOpacity=None,strokeColor=Color(.445938,.54902,.502521,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(68.45669,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(78.80315,4.205276,'4',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Rect(91.27559,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.445938,.54902,.502521,1),fillOpacity=None,strokeColor=Color(.445938,.54902,.502521,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(91.96535,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.44194,.54618,.50283,1),fillOpacity=None,strokeColor=Color(.44194,.54618,.50283,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(92.65512,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.437941,.54334,.503139,1),fillOpacity=None,strokeColor=Color(.437941,.54334,.503139,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(93.34488,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.433942,.5405,.503448,1),fillOpacity=None,strokeColor=Color(.433942,.5405,.503448,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(94.03465,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.429943,.537661,.503757,1),fillOpacity=None,strokeColor=Color(.429943,.537661,.503757,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(94.72441,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.425944,.534821,.504066,1),fillOpacity=None,strokeColor=Color(.425944,.534821,.504066,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(95.41417,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.421945,.531981,.504376,1),fillOpacity=None,strokeColor=Color(.421945,.531981,.504376,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(96.10394,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.417946,.529141,.504685,1),fillOpacity=None,strokeColor=Color(.417946,.529141,.504685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(96.7937,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.413948,.526302,.504994,1),fillOpacity=None,strokeColor=Color(.413948,.526302,.504994,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(97.48346,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.409949,.523462,.505303,1),fillOpacity=None,strokeColor=Color(.409949,.523462,.505303,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(98.17323,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.40595,.520622,.505612,1),fillOpacity=None,strokeColor=Color(.40595,.520622,.505612,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(98.86299,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.401951,.517782,.505921,1),fillOpacity=None,strokeColor=Color(.401951,.517782,.505921,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(99.55276,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.397952,.514943,.50623,1),fillOpacity=None,strokeColor=Color(.397952,.514943,.50623,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(100.2425,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.393953,.512103,.506539,1),fillOpacity=None,strokeColor=Color(.393953,.512103,.506539,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(100.9323,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.389955,.509263,.506848,1),fillOpacity=None,strokeColor=Color(.389955,.509263,.506848,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(101.622,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.385956,.506423,.507157,1),fillOpacity=None,strokeColor=Color(.385956,.506423,.507157,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(102.3118,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.381957,.503584,.507466,1),fillOpacity=None,strokeColor=Color(.381957,.503584,.507466,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(103.0016,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.377958,.500744,.507776,1),fillOpacity=None,strokeColor=Color(.377958,.500744,.507776,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(103.6913,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.373959,.497904,.508085,1),fillOpacity=None,strokeColor=Color(.373959,.497904,.508085,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(104.3811,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.36996,.495064,.508394,1),fillOpacity=None,strokeColor=Color(.36996,.495064,.508394,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(105.0709,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.365962,.492224,.508703,1),fillOpacity=None,strokeColor=Color(.365962,.492224,.508703,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(105.7606,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.361963,.489385,.509012,1),fillOpacity=None,strokeColor=Color(.361963,.489385,.509012,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(106.4504,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.357964,.486545,.509321,1),fillOpacity=None,strokeColor=Color(.357964,.486545,.509321,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(107.1402,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.353965,.483705,.50963,1),fillOpacity=None,strokeColor=Color(.353965,.483705,.50963,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(107.8299,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.349966,.480865,.509939,1),fillOpacity=None,strokeColor=Color(.349966,.480865,.509939,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(108.5197,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.345967,.478026,.510248,1),fillOpacity=None,strokeColor=Color(.345967,.478026,.510248,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(109.2094,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.341969,.475186,.510557,1),fillOpacity=None,strokeColor=Color(.341969,.475186,.510557,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(109.8992,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.33797,.472346,.510866,1),fillOpacity=None,strokeColor=Color(.33797,.472346,.510866,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(110.589,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.333971,.469506,.511176,1),fillOpacity=None,strokeColor=Color(.333971,.469506,.511176,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(111.2787,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.329972,.466667,.511485,1),fillOpacity=None,strokeColor=Color(.329972,.466667,.511485,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(91.27559,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(101.622,4.205276,'5',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Rect(114.0945,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.329972,.466667,.511485,1),fillOpacity=None,strokeColor=Color(.329972,.466667,.511485,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(114.7843,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.325973,.463827,.511794,1),fillOpacity=None,strokeColor=Color(.325973,.463827,.511794,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(115.474,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.321974,.460987,.512103,1),fillOpacity=None,strokeColor=Color(.321974,.460987,.512103,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(116.1638,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.317975,.458147,.512412,1),fillOpacity=None,strokeColor=Color(.317975,.458147,.512412,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(116.8535,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.313977,.455308,.512721,1),fillOpacity=None,strokeColor=Color(.313977,.455308,.512721,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(117.5433,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.309978,.452468,.51303,1),fillOpacity=None,strokeColor=Color(.309978,.452468,.51303,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(118.2331,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.305979,.449628,.513339,1),fillOpacity=None,strokeColor=Color(.305979,.449628,.513339,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(118.9228,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.30198,.446788,.513648,1),fillOpacity=None,strokeColor=Color(.30198,.446788,.513648,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(119.6126,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.297981,.443949,.513957,1),fillOpacity=None,strokeColor=Color(.297981,.443949,.513957,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(120.3024,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.293982,.441109,.514266,1),fillOpacity=None,strokeColor=Color(.293982,.441109,.514266,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(120.9921,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.289984,.438269,.514575,1),fillOpacity=None,strokeColor=Color(.289984,.438269,.514575,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(121.6819,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.285985,.435429,.514885,1),fillOpacity=None,strokeColor=Color(.285985,.435429,.514885,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(122.3717,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.281986,.43259,.515194,1),fillOpacity=None,strokeColor=Color(.281986,.43259,.515194,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(123.0614,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.277987,.42975,.515503,1),fillOpacity=None,strokeColor=Color(.277987,.42975,.515503,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(123.7512,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.273988,.42691,.515812,1),fillOpacity=None,strokeColor=Color(.273988,.42691,.515812,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(124.4409,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.269989,.42407,.516121,1),fillOpacity=None,strokeColor=Color(.269989,.42407,.516121,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(125.1307,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.265991,.421231,.51643,1),fillOpacity=None,strokeColor=Color(.265991,.421231,.51643,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(125.8205,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.261992,.418391,.516739,1),fillOpacity=None,strokeColor=Color(.261992,.418391,.516739,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(126.5102,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.257993,.415551,.517048,1),fillOpacity=None,strokeColor=Color(.257993,.415551,.517048,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(127.2,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.253994,.412711,.517357,1),fillOpacity=None,strokeColor=Color(.253994,.412711,.517357,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(127.8898,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.249995,.409872,.517666,1),fillOpacity=None,strokeColor=Color(.249995,.409872,.517666,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(128.5795,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.245996,.407032,.517975,1),fillOpacity=None,strokeColor=Color(.245996,.407032,.517975,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(129.2693,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.241997,.404192,.518285,1),fillOpacity=None,strokeColor=Color(.241997,.404192,.518285,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(129.9591,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.237999,.401352,.518594,1),fillOpacity=None,strokeColor=Color(.237999,.401352,.518594,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(130.6488,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.234,.398513,.518903,1),fillOpacity=None,strokeColor=Color(.234,.398513,.518903,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(131.3386,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.230001,.395673,.519212,1),fillOpacity=None,strokeColor=Color(.230001,.395673,.519212,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(132.0283,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.226002,.392833,.519521,1),fillOpacity=None,strokeColor=Color(.226002,.392833,.519521,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(132.7181,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.222003,.389993,.51983,1),fillOpacity=None,strokeColor=Color(.222003,.389993,.51983,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(133.4079,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.218004,.387153,.520139,1),fillOpacity=None,strokeColor=Color(.218004,.387153,.520139,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(134.0976,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.214006,.384314,.520448,1),fillOpacity=None,strokeColor=Color(.214006,.384314,.520448,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(114.0945,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(124.4409,4.205276,'6',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Rect(136.9134,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.214006,.384314,.520448,1),fillOpacity=None,strokeColor=Color(.214006,.384314,.520448,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(137.6031,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.210007,.381474,.520757,1),fillOpacity=None,strokeColor=Color(.210007,.381474,.520757,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(138.2929,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.206008,.378634,.521066,1),fillOpacity=None,strokeColor=Color(.206008,.378634,.521066,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(138.9827,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.202009,.375794,.521375,1),fillOpacity=None,strokeColor=Color(.202009,.375794,.521375,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(139.6724,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.19801,.372955,.521685,1),fillOpacity=None,strokeColor=Color(.19801,.372955,.521685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(140.3622,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.194011,.370115,.521994,1),fillOpacity=None,strokeColor=Color(.194011,.370115,.521994,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(141.052,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.190013,.367275,.522303,1),fillOpacity=None,strokeColor=Color(.190013,.367275,.522303,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(141.7417,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.186014,.364435,.522612,1),fillOpacity=None,strokeColor=Color(.186014,.364435,.522612,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(142.4315,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.182015,.361596,.522921,1),fillOpacity=None,strokeColor=Color(.182015,.361596,.522921,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(143.1213,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.178016,.358756,.52323,1),fillOpacity=None,strokeColor=Color(.178016,.358756,.52323,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(143.811,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.174017,.355916,.523539,1),fillOpacity=None,strokeColor=Color(.174017,.355916,.523539,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(144.5008,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.170018,.353076,.523848,1),fillOpacity=None,strokeColor=Color(.170018,.353076,.523848,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(145.1906,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.16602,.350237,.524157,1),fillOpacity=None,strokeColor=Color(.16602,.350237,.524157,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(145.8803,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.162021,.347397,.524466,1),fillOpacity=None,strokeColor=Color(.162021,.347397,.524466,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(146.5701,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.158022,.344557,.524775,1),fillOpacity=None,strokeColor=Color(.158022,.344557,.524775,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(147.2598,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.154023,.341717,.525085,1),fillOpacity=None,strokeColor=Color(.154023,.341717,.525085,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(147.9496,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.150024,.338878,.525394,1),fillOpacity=None,strokeColor=Color(.150024,.338878,.525394,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(148.6394,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.146025,.336038,.525703,1),fillOpacity=None,strokeColor=Color(.146025,.336038,.525703,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(149.3291,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.142026,.333198,.526012,1),fillOpacity=None,strokeColor=Color(.142026,.333198,.526012,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(150.0189,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.138028,.330358,.526321,1),fillOpacity=None,strokeColor=Color(.138028,.330358,.526321,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(150.7087,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.134029,.327519,.52663,1),fillOpacity=None,strokeColor=Color(.134029,.327519,.52663,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(151.3984,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.13003,.324679,.526939,1),fillOpacity=None,strokeColor=Color(.13003,.324679,.526939,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(152.0882,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.126031,.321839,.527248,1),fillOpacity=None,strokeColor=Color(.126031,.321839,.527248,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(152.778,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.122032,.318999,.527557,1),fillOpacity=None,strokeColor=Color(.122032,.318999,.527557,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(153.4677,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.118033,.31616,.527866,1),fillOpacity=None,strokeColor=Color(.118033,.31616,.527866,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(154.1575,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.114035,.31332,.528175,1),fillOpacity=None,strokeColor=Color(.114035,.31332,.528175,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(154.8472,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.110036,.31048,.528484,1),fillOpacity=None,strokeColor=Color(.110036,.31048,.528484,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(155.537,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.106037,.30764,.528794,1),fillOpacity=None,strokeColor=Color(.106037,.30764,.528794,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(156.2268,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.102038,.304801,.529103,1),fillOpacity=None,strokeColor=Color(.102038,.304801,.529103,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(156.9165,0,.689764,15.59055,rx=0,ry=0,fillColor=Color(.098039,.301961,.529412,1),fillOpacity=None,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(136.9134,0,20.69291,15.59055,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(147.2598,4.205276,'7',textAnchor='middle',fontName='Helvetica-Bold',fontSize=10,fillColor=Color(1,1,1,1),strokeColor=Color(0,0,0,1)))
		v0.add(Polygon(points=[147.2598,13.88976,141.874,17.29134,152.6457,17.29134,147.2598,13.88976],fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Polygon(points=[147.2598,1.700787,141.874,-1.700787,152.6457,-1.700787,147.2598,1.700787],fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=.58,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(String(157.6063,-13.37008,'Source: ReportLab',textAnchor='end',fontName='Helvetica-Oblique',fontSize=6,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
