#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Line, String, PolyLine
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(50,50,300,125,rx=0,ry=0,fillColor=Color(1,1,1,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=2,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(50,50,9.245484,125,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(59.24548,50,57.70457,125,rx=0,ry=0,fillColor=Color(.678431,.847059,.901961,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(116.9501,50,58.661,125,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(175.6111,50,57.70457,125,rx=0,ry=0,fillColor=Color(.678431,.847059,.901961,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(233.3156,50,58.661,125,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(291.9766,50,58.02338,125,rx=0,ry=0,fillColor=Color(.678431,.847059,.901961,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(350,50,0,125,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,350,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(59.24548,50,59.24548,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(116.9501,50,116.9501,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(175.6111,50,175.6111,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(233.3156,50,233.3156,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(291.9766,50,291.9766,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(350,50,350,45,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,59.24548,42)
		v0.add(String(0,-4,'12/97',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,116.9501,42)
		v0.add(String(0,-4,'06/98',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,175.6111,42)
		v0.add(String(0,-4,'12/98',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,233.3156,42)
		v0.add(String(0,-4,'06/99',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,291.9766,42)
		v0.add(String(0,-4,'12/99',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,350,42)
		v0.add(String(0,-4,'06/00',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(50,50,50,175,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,50,45,50,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,89.55696,45,89.55696,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,129.1139,45,129.1139,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(50,168.6709,45,168.6709,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=10,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,50)
		v0.add(String(-30.83,-4,'  100% ',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,89.55696)
		v0.add(String(-30.83,-4,'  105% ',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,129.1139)
		v0.add(String(-30.83,-4,'  110% ',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,45,168.6709)
		v0.add(String(-30.83,-4,'  115% ',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(PolyLine(points=[50,50,59.24548,51.34839,69.12859,62.37308,78.05526,67.31007,87.93836,62.92505,97.50266,71.86744,107.3858,73.09971,116.9501,75.7863,126.8332,75.72502,136.7163,93.31039,146.2806,123.768,156.1637,144.8254,165.7279,136.3803,175.6111,136.3803,185.4942,144.8438,194.4208,127.4625,204.3039,131.0277,213.8682,132.4995,223.7513,123.8889,233.3156,115.1438,243.1987,130.7986,253.0818,136.7746,262.6461,148.4378,272.5292,150.7231,282.0935,147.7133,291.9766,147.8328,301.8597,136.4361,311.1052,133.2803,320.9883,155.3134,330.5526,137.3806,340.4357,142.5848,350,157.4622],strokeColor=PCMYKColor(100,65,0,30,spotName='PANTONE 288 CV',alpha=100),strokeWidth=2,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[50,50,59.24548,50,69.12859,56.32911,78.05526,65.82278,87.93836,65.03165,97.50266,73.73418,107.3858,73.73418,116.9501,74.52532,126.8332,74.52532,136.7163,72.1519,146.2806,94.3038,156.1637,115.6646,165.7279,114.0823,175.6111,144.1456,185.4942,153.6392,194.4208,130.6962,204.3039,143.3544,213.8682,147.3101,223.7513,129.9051,233.3156,123.5759,243.1987,138.6076,253.0818,142.5633,262.6461,149.6835,272.5292,154.4304,282.0935,159.9684,291.9766,171.8354,301.8597,150.4747,311.1052,159.9684,320.9883,175,330.5526,146.519,340.4357,149.6835,350,165.5063],strokeColor=PCMYKColor(0,79,91,0,spotName='PANTONE Wm Red CV',alpha=100),strokeWidth=1,strokeLineCap=0,strokeLineJoin=1,strokeMiterLimit=0,strokeDashArray=[3,1],strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
