#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=100,height=100,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(0,0,5,100,rx=0,ry=0,fillColor=Color(1,.752941,.796078,1),fillOpacity=None,strokeColor=Color(1,.752941,.796078,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(5,0,5,100,rx=0,ry=0,fillColor=Color(.947368,.713313,.75418,1),fillOpacity=None,strokeColor=Color(.947368,.713313,.75418,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(10,0,5,100,rx=0,ry=0,fillColor=Color(.894737,.673684,.712281,1),fillOpacity=None,strokeColor=Color(.894737,.673684,.712281,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(15,0,5,100,rx=0,ry=0,fillColor=Color(.842105,.634056,.670382,1),fillOpacity=None,strokeColor=Color(.842105,.634056,.670382,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,0,5,100,rx=0,ry=0,fillColor=Color(.789474,.594427,.628483,1),fillOpacity=None,strokeColor=Color(.789474,.594427,.628483,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(25,0,5,100,rx=0,ry=0,fillColor=Color(.736842,.554799,.586584,1),fillOpacity=None,strokeColor=Color(.736842,.554799,.586584,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(30,0,5,100,rx=0,ry=0,fillColor=Color(.684211,.51517,.544685,1),fillOpacity=None,strokeColor=Color(.684211,.51517,.544685,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(35,0,5,100,rx=0,ry=0,fillColor=Color(.631579,.475542,.502786,1),fillOpacity=None,strokeColor=Color(.631579,.475542,.502786,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(40,0,5,100,rx=0,ry=0,fillColor=Color(.578947,.435913,.460888,1),fillOpacity=None,strokeColor=Color(.578947,.435913,.460888,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(45,0,5,100,rx=0,ry=0,fillColor=Color(.526316,.396285,.418989,1),fillOpacity=None,strokeColor=Color(.526316,.396285,.418989,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(50,0,5,100,rx=0,ry=0,fillColor=Color(.473684,.356656,.37709,1),fillOpacity=None,strokeColor=Color(.473684,.356656,.37709,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(55,0,5,100,rx=0,ry=0,fillColor=Color(.421053,.317028,.335191,1),fillOpacity=None,strokeColor=Color(.421053,.317028,.335191,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(60,0,5,100,rx=0,ry=0,fillColor=Color(.368421,.277399,.293292,1),fillOpacity=None,strokeColor=Color(.368421,.277399,.293292,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(65,0,5,100,rx=0,ry=0,fillColor=Color(.315789,.237771,.251393,1),fillOpacity=None,strokeColor=Color(.315789,.237771,.251393,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(70,0,5,100,rx=0,ry=0,fillColor=Color(.263158,.198142,.209494,1),fillOpacity=None,strokeColor=Color(.263158,.198142,.209494,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(75,0,5,100,rx=0,ry=0,fillColor=Color(.210526,.158514,.167595,1),fillOpacity=None,strokeColor=Color(.210526,.158514,.167595,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(80,0,5,100,rx=0,ry=0,fillColor=Color(.157895,.118885,.125697,1),fillOpacity=None,strokeColor=Color(.157895,.118885,.125697,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(85,0,5,100,rx=0,ry=0,fillColor=Color(.105263,.079257,.083798,1),fillOpacity=None,strokeColor=Color(.105263,.079257,.083798,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(90,0,5,100,rx=0,ry=0,fillColor=Color(.052632,.039628,.041899,1),fillOpacity=None,strokeColor=Color(.052632,.039628,.041899,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,0,5,100,rx=0,ry=0,fillColor=Color(0,0,0,1),fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(0,0,100,100,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=2,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
