#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Line, Circle, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=76.85768503937007,height=78.85568503937007,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(30,5,42.51969,42.51969,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(30,19.17323,72.51969,19.17323,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(30,33.34646,72.51969,33.34646,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(44.17323,5,44.17323,47.51969,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(58.34646,5,58.34646,47.51969,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Circle(44.17323,19.17323,5.669291,fillColor=Color(.909804,.878431,.466667,1),fillOpacity=None,strokeColor=Color(.098039,.301961,.529412,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(String(25,-2113.567,'Large',textAnchor='end',fontName='Helvetica',fontSize=6,fillColor=PCMYKColor(0,0,0,100,alpha=100),strokeColor=Color(.098039,.301961,.529412,1)))
		self.add(String(25,-2127.74,'Medium',textAnchor='end',fontName='Helvetica',fontSize=6,fillColor=PCMYKColor(0,0,0,100,alpha=100),strokeColor=Color(.098039,.301961,.529412,1)))
		self.add(String(25,-2141.913,'Small',textAnchor='end',fontName='Helvetica',fontSize=6,fillColor=PCMYKColor(0,0,0,100,alpha=100),strokeColor=Color(.098039,.301961,.529412,1)))
		v0=self._nn(Group())
		v0.transform = (0,1,-1,0,2191.087,52.51969)
		v0.add(String(0,1.2,'Value',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=PCMYKColor(0,0,0,100,alpha=100)))
		v0=self._nn(Group())
		v0.transform = (0,1,-1,0,2205.26,52.51969)
		v0.add(String(0,1.2,'Blend',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=PCMYKColor(0,0,0,100,alpha=100)))
		v0=self._nn(Group())
		v0.transform = (0,1,-1,0,2219.433,52.51969)
		v0.add(String(0,1.2,'Growth',textAnchor='start',fontName='Helvetica',fontSize=6,fillColor=PCMYKColor(0,0,0,100,alpha=100)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
